.. _wiki_background:

==========
Background
==========

This version of the :app:`Pyramid` wiki tutorial presents a
:app:`Pyramid` application that uses technologies which will be
familiar to someone with :term:`Zope` experience.  It uses
:term:`ZODB` as a persistence mechanism and :term:`traversal` to map
URLs to code.  It can also be followed by people without any prior
Python web framework experience.

To code along with this tutorial, the developer will need a Unix
machine with development tools (macOS with XCode, any Linux or BSD
variant, and so on) *or* a Windows system of any kind.

.. warning::

  This tutorial has been written for Python 2.  It is unlikely to work
  without modification under Python 3.

Have fun!
